@@ -245,9 +245,9 @@ tbl[list(1), ]
 tbl["1", ]
 
 ## ----bracket-i-oob, dftbl = TRUE----------------------------------------------
-df[10, ]
+
 tbl[10, ]
-df["x", ]
+
 tbl["x", ]
 
 ## ----bracket-i-recycle, dftbl = TRUE------------------------------------------
